@@ -13,8 +13,9 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Harmony.  If not, see <http://www.gnu.org/licenses/>.
+# along with Harmony.  If not, see <https://www.gnu.org/licenses/>.
 
-from . import harmony, discord  # noqa: F401
-from .harmony import __version__  # noqa: F401
-from .__main__ import main  # noqa: F401
+# flake8: noqa
+from . import harmony, discord
+from .harmony import __version__
+from .__main__ import main
