@@ -13,7 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Harmony.  If not, see <http://www.gnu.org/licenses/>.
+# along with Harmony.  If not, see <https://www.gnu.org/licenses/>.
 
 from . import discord
 from . import keyring
@@ -37,9 +37,10 @@ import re
 import sys
 import traceback
 
-__version__ = "0.7.0"
+__version__ = "0.7.1"
 RECAPTCHA_API_KEY = "6Lef5iQTAAAAAKeIvIY-DeexoO3gj7ryl9rLMEnn"
 RECAPTCHA_SITE_URL = "https://discord.com"
+LIBRECAPTCHA_GUI = not os.getenv("LIBRECAPTCHA_NO_GUI")
 
 INTERACTIVE_HELP = """\
 Commands:
@@ -277,7 +278,7 @@ class DiscordCli:
         self.handle_response(error_message, response, throw=throw)
         return response
 
-    def handle_response(self, error_message, response, *, throw):
+    def handle_response(self, error_message, response, *, throw: bool):
         if response.success:
             return
         if error_message is not None:
@@ -293,8 +294,11 @@ class DiscordCli:
         while True:
             try:
                 token = librecaptcha.get_token(
-                    RECAPTCHA_API_KEY, RECAPTCHA_SITE_URL, self.user_agent,
-                    gui=librecaptcha.has_gui(), debug=self.debug,
+                    api_key=RECAPTCHA_API_KEY,
+                    site_url=RECAPTCHA_SITE_URL,
+                    user_agent=self.user_agent,
+                    gui=(LIBRECAPTCHA_GUI and librecaptcha.has_gui()),
+                    debug=self.debug,
                 )
             except Exception:
                 stderr("\nError encountered while solving the CAPTCHA:\n")
@@ -308,7 +312,12 @@ class DiscordCli:
             return token
 
     def try_once_with_captcha(
-            self, error_message, func, *, throw=True, ask=True):
+        self,
+        error_message,
+        func, *,
+        throw=True,
+        ask=True,
+    ):
         response = self.try_request(lambda: func(None))
         if not response.needs_captcha:
             self.handle_response(error_message, response, throw=throw)
